@@ -487,8 +487,10 @@ int main(int argc, char **argv)
     {
 	if (run.logfile && access(run.logfile, F_OK) == 0)
     	{
-	    freopen(run.logfile, "a", stdout);
-	    freopen(run.logfile, "a", stderr);
+	    if (!freopen(run.logfile, "a", stdout))
+		    report(stderr, GT_("could not open %s to append logs to \n"), run.logfile);
+	    if (!freopen(run.logfile, "a", stderr))
+		    report(stdout, GT_("could not open %s to append logs to \n"), run.logfile);
     	}
     }
 
@@ -871,6 +873,7 @@ static int load_params(int argc, char **argv, int optind)
 
     def_opts.server.protocol = P_AUTO;
     def_opts.server.timeout = CLIENT_TIMEOUT;
+    def_opts.server.esmtp_name = user;
     def_opts.warnings = WARNING_INTERVAL;
     def_opts.remotename = user;
     def_opts.listener = SMTP_MODE;
@@ -1202,10 +1205,7 @@ static void terminate_poll(int sig)
 	    {
 		/* don't send QUIT for ODMR case because we're acting
 		   as a proxy between the SMTP server and client. */
-		if (ctl->server.protocol != P_ODMR)
-		    SMTP_quit(ctl->smtp_socket);
-		SockClose(ctl->smtp_socket);
-		ctl->smtp_socket = -1;
+		smtp_close(ctl, ctl->server.protocol != P_ODMR);
 	    }
     }
 
