@@ -31,7 +31,7 @@ void lock_setup(void)
 #define	FETCHMAIL_PIDFILE	"fetchmail.pid"
     if (!getuid()) {
 	lockfile = (char *)xmalloc(
-		sizeof(PID_DIR) + sizeof(FETCHMAIL_PIDFILE));
+		sizeof(PID_DIR) + sizeof(FETCHMAIL_PIDFILE) + 1);
 	sprintf(lockfile, "%s/%s", PID_DIR, FETCHMAIL_PIDFILE);
     } else {
 	lockfile = (char *)xmalloc(strlen(fmhome)+sizeof(FETCHMAIL_PIDFILE)+2);
@@ -78,7 +78,7 @@ int lock_state(void)
 	bkgd = (fscanf(lockfp, "%d %d", &pid, &st) == 2);
 
 	if (kill(pid, 0) == -1) {
-	    fprintf(stderr,_("fetchmail: removing stale lockfile\n"));
+	    fprintf(stderr,GT_("fetchmail: removing stale lockfile\n"));
 	    pid = 0;
 	    unlink(lockfile);
 	}
@@ -119,7 +119,7 @@ void lock_or_die(void)
       }
       else
       {
-	  fprintf(stderr,	_("fetchmail: lock creation failed.\n"));
+	  fprintf(stderr,	GT_("fetchmail: lock creation failed.\n"));
 	  exit(PS_EXCLUDE);
       }
     }
