@@ -48,7 +48,9 @@ static int odmr_getrange(int sock, struct query *ctl, const char *id,
     char buf [MSGBUFSIZE+1];
     struct idlist *qnp;		/* pointer to Q names */
 
-    if ((ok = SMTP_ehlo(sock, fetchmailhost, &opts)))
+    if ((ok = SMTP_ehlo(sock, fetchmailhost, 
+			ctl->server.esmtp_name, ctl->server.esmtp_password,
+			&opts)))
     {
 	report(stderr, GT_("%s's SMTP listener does not support ESMTP\n"),
 	      ctl->server.pollname);
@@ -93,12 +95,12 @@ static int odmr_getrange(int sock, struct query *ctl, const char *id,
     switch(atoi(buf))
     {
     case 250:	/* OK, turnaround is about to happe */
-	if (outlevel >= O_SILENT)
+	if (outlevel > O_SILENT)
 	    report(stdout, GT_("Turnaround now...\n"));
 	break;
 
     case 450:	/* ATRN request refused */
-	if (outlevel >= O_SILENT)
+	if (outlevel > O_SILENT)
 	    report(stdout, GT_("ATRN request refused.\n"));
 	return(PS_PROTOCOL);
 
@@ -107,7 +109,8 @@ static int odmr_getrange(int sock, struct query *ctl, const char *id,
 	return(PS_EXCLUDE);
 
     case 453:	/* You have no mail */
-	report(stderr, GT_("You have no mail.\n"));
+	if (outlevel > O_SILENT)
+	    report(stderr, GT_("You have no mail.\n"));
 	return(PS_NOMAIL);
 
     case 502:	/* Command not implemented */
