@@ -46,17 +46,29 @@
 /* makes the open_sink()/close_sink() pair non-reentrant */
 static int lmtp_responses;
 
+void smtp_close(struct query *ctl, int sayquit)
+/* close the socket to SMTP server */
+{
+    if (ctl->smtp_socket != -1)
+    {
+	if (sayquit)
+	    SMTP_quit(ctl->smtp_socket);
+	SockClose(ctl->smtp_socket);
+	ctl->smtp_socket = -1;
+    }
+    batchcount = 0;
+}
+
 int smtp_open(struct query *ctl)
 /* try to open a socket to the appropriate SMTP server for this query */ 
 {
     char *parsed_host = NULL;
 
     /* maybe it's time to close the socket in order to force delivery */
-    if (NUM_NONZERO(ctl->batchlimit) && (ctl->smtp_socket != -1) && ++batchcount == ctl->batchlimit)
-    {
-	SockClose(ctl->smtp_socket);
-	ctl->smtp_socket = -1;
-	batchcount = 0;
+    if (NUM_NONZERO(ctl->batchlimit)) {
+	if (batchcount == ctl->batchlimit)
+	    smtp_close(ctl, 1);
+	batchcount++;
     }
 
     /* if no socket to any SMTP host is already set up, try to open one */
@@ -131,23 +143,27 @@ int smtp_open(struct query *ctl)
 
 	    /* return immediately for ODMR */
 	    if (ctl->server.protocol == P_ODMR)
+	    {
+	       set_timeout(0);
+	       phase = oldphase;
                return(ctl->smtp_socket); /* success */
+	    }
 
 	    /* are we doing SMTP or LMTP? */
 	    SMTP_setmode(ctl->listener);
 
 	    /* first, probe for ESMTP */
 	    if (SMTP_ok(ctl->smtp_socket) == SM_OK &&
-		    SMTP_ehlo(ctl->smtp_socket, id_me,
-			  &ctl->server.esmtp_options) == SM_OK)
+		    SMTP_ehlo(ctl->smtp_socket, id_me, 
+			      ctl->server.esmtp_name, ctl->server.esmtp_password,
+			      &ctl->server.esmtp_options) == SM_OK)
 	       break;  /* success */
 
 	    /*
 	     * RFC 1869 warns that some listeners hang up on a failed EHLO,
 	     * so it's safest not to assume the socket will still be good.
 	     */
-	    SockClose(ctl->smtp_socket);
-	    ctl->smtp_socket = -1;
+	    smtp_close(ctl, 0);
 
 	    /* if opening for ESMTP failed, try SMTP */
 	    if ((ctl->smtp_socket = SockOpen(parsed_host,portnum,NULL,
@@ -158,8 +174,7 @@ int smtp_open(struct query *ctl)
 		    SMTP_helo(ctl->smtp_socket, id_me) == SM_OK)
 		break;  /* success */
 
-	    SockClose(ctl->smtp_socket);
-	    ctl->smtp_socket = -1;
+	    smtp_close(ctl, 0);
 	}
 	set_timeout(0);
 	phase = oldphase;
@@ -443,7 +458,7 @@ static int handle_smtp_report(struct query *ctl, struct msgblk *msg)
 	 *
 	 * Bouncemail *might* be appropriate here as a delay
 	 * notification (note; if we ever add this, we must make
-	 * sure the RFC1894 Action field is "delayed" rather thwn
+	 * sure the RFC1894 Action field is "delayed" rather than
 	 * "failed").  But it's not really necessary because
 	 * these are not actual failures, we're very likely to be
 	 * able to recover on the next cycle.
@@ -603,6 +618,7 @@ static int open_smtp_sink(struct query *ctl, struct msgblk *msg,
     char		**from_responses;
 #endif /* EXPLICIT_BOUNCE_ON_BAD_ADDRESS */
     int		total_addresses;
+    int		force_transient_error;
 
     /*
      * Compute ESMTP options.
@@ -692,14 +708,14 @@ static int open_smtp_sink(struct query *ctl, struct msgblk *msg,
 	    else {
 		if (ctl->smtpname) {
 #ifdef HAVE_SNPRINTF
-		    snprintf(addr, sizeof(addr)-1, "%s", ctl->smtpname);
+		    snprintf(addr, sizeof(addr), "%s", ctl->smtpname);
 #else
 		    sprintf(addr, "%s", ctl->smtpname);
 #endif /* HAVE_SNPRINTF */
 
 		} else {
 #ifdef HAVE_SNPRINTF
-		  snprintf(addr, sizeof(addr)-1, "%s@%s", idp->id, ctl->destaddr);
+		  snprintf(addr, sizeof(addr), "%s@%s", idp->id, ctl->destaddr);
 #else
 		  sprintf(addr, "%s@%s", idp->id, ctl->destaddr);
 #endif /* HAVE_SNPRINTF */
@@ -712,7 +728,8 @@ static int open_smtp_sink(struct query *ctl, struct msgblk *msg,
 #ifdef EXPLICIT_BOUNCE_ON_BAD_ADDRESS
  		    char errbuf[POPBUFSIZE];
 #endif /* EXPLICIT_BOUNCE_ON_BAD_ADDRESS */
-		handle_smtp_report(ctl, msg);
+		if (handle_smtp_report(ctl, msg) == PS_TRANSIENT)
+		    force_transient_error = 1;
 
 #ifdef EXPLICIT_BOUNCE_ON_BAD_ADDRESS
 #ifdef HAVE_SNPRINTF
@@ -759,6 +776,14 @@ static int open_smtp_sink(struct query *ctl, struct msgblk *msg,
      */
     if (!(*good_addresses)) 
     {
+	if (force_transient_error) {
+		/* do not risk dataloss due to overengineered multidrop
+		 * crap. If one of the recipients returned PS_TRANSIENT,
+		 * we return exactly that.
+		 */
+		SMTP_rset(ctl->smtp_socket);        /* required by RFC1870 */
+		return(PS_TRANSIENT);
+	}
 	if (!run.postmaster[0])
 	{
 	    if (outlevel >= O_VERBOSE)
@@ -771,7 +796,7 @@ static int open_smtp_sink(struct query *ctl, struct msgblk *msg,
 	else
 	{
 #ifdef HAVE_SNPRINTF
-	    snprintf(addr, sizeof(addr)-1, "%s@%s", run.postmaster, ctl->destaddr);
+	    snprintf(addr, sizeof(addr), "%s@%s", run.postmaster, ctl->destaddr);
 #else
 	    sprintf(addr, "%s@%s", run.postmaster, ctl->destaddr);
 #endif /* HAVE_SNPRINTF */
@@ -1015,8 +1040,11 @@ int open_sink(struct query *ctl, struct msgblk *msg,
 	/* 
 	 * User was delivering locally.  We have a fallback MDA.
 	 * Latch it in place, logging the error, and fall through.
+	 * Set stripcr as we would if MDA had been the initial transport
 	 */
 	ctl->mda = FALLBACK_MDA;
+	if (!ctl->forcecr)
+	    ctl->stripcr = TRUE;
 
 	report(stderr, GT_("can't raise the listener; falling back to %s"),
 			 FALLBACK_MDA);
@@ -1212,7 +1240,8 @@ int open_warning_by_mail(struct query *ctl, struct msgblk *msg)
     struct msgblk reply = {NULL, NULL, "FETCHMAIL-DAEMON@", 0};
     int status;
 
-    strcat(reply.return_path, fetchmailhost);
+    strcat(reply.return_path, ctl->smtpaddress ? ctl->smtpaddress :
+	    fetchmailhost);
 
     if (!MULTIDROP(ctl))		/* send to calling user */
     {
