@@ -36,7 +36,6 @@
 #else
 #include <varargs.h>
 #endif
-#include <signal.h>
 #include "socket.h"
 #include "fetchmail.h"
 #include "i18n.h"
@@ -68,6 +67,8 @@ static int h_errno;
 
 #endif /* ndef h_errno */
 
+extern int mailserver_socket_temp;	/* Socket to close if connect timeout */
+
 #if NET_SECURITY
 #include <net/security.h>
 #endif /* NET_SECURITY */
@@ -219,11 +220,7 @@ int SockCheckOpen(int fd)
 
 int UnixOpen(const char *path)
 {
-#ifdef HAVE_SIGPROCMASK
-    sigset_t	allsigs;
-#endif /* HAVE_SIGPROCMASK */
-
-    int stat, sock = -1;
+    int sock = -1;
     struct sockaddr_un ad;
     memset(&ad, 0, sizeof(ad));
     ad.sun_family = AF_UNIX;
@@ -236,13 +233,12 @@ int UnixOpen(const char *path)
 	return -1;
     }
 
-#ifdef HAVE_SIGPROCMASK
-    /* avoid socket leak on alarm signal during connect(2) */
-    sigfillset(&allsigs);
-    sigprocmask(SIG_BLOCK, &allsigs, NULL);
-#endif /* HAVE_SIGPROCMASK */
-
-    if (connect(sock, (struct sockaddr *) &ad, sizeof(ad)) < 0)
+	/* Socket opened saved. Usefull if connect timeout 
+	 * because it can be closed.
+	 */
+	mailserver_socket_temp = sock;
+    
+	if (connect(sock, (struct sockaddr *) &ad, sizeof(ad)) < 0)
     {
 	int olderr = errno;
 	fm_close(sock);	/* don't use SockClose, no traffic yet */
@@ -250,10 +246,9 @@ int UnixOpen(const char *path)
 	errno = olderr;
 	sock = -1;
     }
-
-#ifdef HAVE_SIGPROCMASK
-    sigprocmask(SIG_UNBLOCK, &allsigs, NULL);
-#endif /* HAVE_SIGPROCMASK */
+	
+	/* No connect timeout, then no need to set mailserver_socket_temp */
+	mailserver_socket_temp = -1;
 
     return sock;
 }
@@ -262,10 +257,6 @@ int UnixOpen(const char *path)
 int SockOpen(const char *host, const char *service, const char *options,
 	     const char *plugin)
 {
-#ifdef HAVE_SIGPROCMASK
-    sigset_t	allsigs;
-#endif /* HAVE_SIGPROCMASK */
-
     struct addrinfo *ai, *ai0, req;
     int i;
 #if NET_SECURITY
@@ -304,29 +295,29 @@ int SockOpen(const char *host, const char *service, const char *options,
 	break;
 #else
 
-#ifdef HAVE_SIGPROCMASK
-    /* avoid socket leak on alarm signal during connect(2) */
-    sigfillset(&allsigs);
-    sigprocmask(SIG_BLOCK, &allsigs, NULL);
-#endif /* HAVE_SIGPROCMASK */
-
     i = -1;
     for (ai = ai0; ai; ai = ai->ai_next) {
 	i = socket(ai->ai_family, ai->ai_socktype, 0);
 	if (i < 0)
 	    continue;
+
+	/* Socket opened saved. Usefull if connect timeout 
+	 * because it can be closed.
+	 */
+	mailserver_socket_temp = i;
+
 	if (connect(i, (struct sockaddr *) ai->ai_addr, ai->ai_addrlen) < 0) {
 	    fm_close(i);
 	    i = -1;
 	    continue;
 	}
+	
+	/* No connect timeout, then no need to set mailserver_socket_temp */
+	mailserver_socket_temp = -1;
+	
 	break;
     }
 
-#ifdef HAVE_SIGPROCMASK
-    sigprocmask(SIG_UNBLOCK, &allsigs, NULL);
-#endif /* HAVE_SIGPROCMASK */
-
 #endif
 #endif /* NET_SECURITY */
 
@@ -389,6 +380,12 @@ int SockOpen(const char *host, int clientPort, const char *options,
             h_errno = 0;
             return -1;
         }
+
+		/* Socket opened saved. Usefull if connect timeout because
+		 * it can be closed
+		 */
+		mailserver_socket_temp = sock;
+		
         if (connect(sock, (struct sockaddr *) &ad, sizeof(ad)) < 0)
         {
             int olderr = errno;
@@ -397,6 +394,10 @@ int SockOpen(const char *host, int clientPort, const char *options,
             errno = olderr;
             return -1;
         }
+
+		/* No connect timeout, then no need to set mailserver_socket_temp */
+		mailserver_socket_temp = -1;
+		
 #ifndef HAVE_INET_ATON
     }
 #else
@@ -434,10 +435,19 @@ int SockOpen(const char *host, int clientPort, const char *options,
 		h_errno = 0;
 		return -1;
 	    }
+
+		/* Socket opened saved. Usefull if connect timeout because
+		 * it can be closed
+		 */
+		mailserver_socket_temp = sock;
+		
 	    ad.sin_port = htons(clientPort);
 	    memcpy(&ad.sin_addr, *pptr, sizeof(struct in_addr));
-	    if (connect(sock, (struct sockaddr *) &ad, sizeof(ad)) == 0)
-		break; /* success */
+	    if (connect(sock, (struct sockaddr *) &ad, sizeof(ad)) == 0) {
+			/* No connect timeout, then no need to set mailserver_socket_temp */
+			mailserver_socket_temp = -1;
+			break; /* success */
+		}	
 	    fm_close(sock);	/* don't use SockClose, no traffic yet */
 	    memset(&ad, 0, sizeof(ad));
 	    ad.sin_family = AF_INET;
@@ -563,13 +573,14 @@ int SockRead(int sock, char *buf, int len)
 			later change the behavior of SSL_peek
 			to "fix" this problem...  :-(	*/
 		if ((n = SSL_peek(ssl, bp, len)) < 0) {
+			(void)SSL_get_error(ssl, n);
 			return(-1);
 		}
 		if( 0 == n ) {
 			/* SSL_peek says no data...  Does he mean no data
 			or did the connection blow up?  If we got an error
 			then bail! */
-			if( 0 != ( n = ERR_get_error() ) ) {
+			if( 0 != ( n = SSL_get_error(ssl, n) ) ) {
 				return -1;
 			}
 			/* We didn't get an error so read at least one
@@ -581,8 +592,13 @@ int SockRead(int sock, char *buf, int len)
 			newline = NULL;
 		} else if ((newline = memchr(bp, '\n', n)) != NULL)
 			n = newline - bp + 1;
-		if ((n = SSL_read(ssl, bp, n)) == -1) {
-			return(-1);
+		/* Matthias Andree: SSL_read can return 0, in that case
+		 * we must cal SSL_get_error to figure if there was
+		 * an error or just a "no data" condition */
+		if ((n = SSL_read(ssl, bp, n)) <= 0) {
+			if ((n = SSL_get_error(ssl, n))) {
+				return(-1);
+			}
 		}
 		/* Check for case where our single character turned out to
 		 * be a newline...  (It wasn't going to get caught by
@@ -635,16 +651,20 @@ int SockPeek(int sock)
 #ifdef	SSL_ENABLE
 	if( NULL != ( ssl = SSLGetContext( sock ) ) ) {
 		n = SSL_peek(ssl, &ch, 1);
+		if (n < 0) {
+			(void)SSL_get_error(ssl, n);
+			return -1;
+		}
 		if( 0 == n ) {
 			/* This code really needs to implement a "hold back"
 			 * to simulate a functioning SSL_peek()...  sigh...
 			 * Has to be coordinated with the read code above.
 			 * Next on the list todo...	*/
 
-			/* SSL_peek says no data...  Does he mean no data
+			/* SSL_peek says 0...  Does that mean no data
 			or did the connection blow up?  If we got an error
 			then bail! */
-			if( 0 != ( n = ERR_get_error() ) ) {
+			if( 0 != ( n = SSL_get_error(ssl, n) ) ) {
 				return -1;
 			}
 
@@ -794,13 +814,16 @@ int SSL_verify_callback( int ok_return, X509_STORE_CTX *ctx, int strict )
 				}
 				tp += esz;
 			}
-			report(stdout, GT_("%s key fingerprint: %s\n"), _server_label, text);
+			if (outlevel > O_NORMAL)
+			    report(stdout, GT_("%s key fingerprint: %s\n"), _server_label, text);
 			if (_check_digest != NULL) {
-				if (strcmp(text, _check_digest) == 0)
+				if (strcmp(text, _check_digest) == 0) {
+				    if (outlevel > O_NORMAL)
 					report(stdout, GT_("%s fingerprints match.\n"), _server_label);
-				else {
+				} else {
+				    if (outlevel > O_SILENT)
 					report(stderr, GT_("%s fingerprints do not match!\n"), _server_label);
-					return (0);
+				    return (0);
 				}
 			}
 		}
